SoftwareInterrupt

Struct SoftwareInterrupt 

#[non_exhaustive]
pub struct SoftwareInterrupt<'d, const NUM: u8> { /* private fields */ }
A software interrupt can be triggered by software.

Implementations

Source

impl<'d, const NUM: u8> SoftwareInterrupt<'d, NUM>

pub const fn new(instance: impl Instance<NUM> + 'd) -> Self

Create a software interrupt driver.

pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)

Available on crate feature unstable only.

Sets the interrupt handler for this software-interrupt

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

#[unsafe(link_section = ".rwtext")]
pub fn raise(&self)

Trigger this software-interrupt

pub fn reset(&self)

Resets this software-interrupt