#[non_exhaustive]pub struct SoftwareInterrupt<'d, const NUM: u8> { /* private fields */ }Expand description
A software interrupt can be triggered by software.
Implementations
Sourceimpl<'d, const NUM: u8> SoftwareInterrupt<'d, NUM>
impl<'d, const NUM: u8> SoftwareInterrupt<'d, NUM>
Sourcepub const fn new(instance: impl Instance<NUM> + 'd) -> Self
pub const fn new(instance: impl Instance<NUM> + 'd) -> Self
Create a software interrupt driver.
Sourcepub fn set_interrupt_handler(&mut self, handler: InterruptHandler)
Available on crate feature unstable only.
pub fn set_interrupt_handler(&mut self, handler: InterruptHandler)
unstable only.Sets the interrupt handler for this software-interrupt
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.